@@ -1,10 +1,21 @@
 ## ----chunk_options, include=FALSE---------------------------------------------
-tiny_width = 5.5
-tiny_height = 3 + 2/3
-small_width = med_width = 6.75
-small_height = med_height = 4.5
-large_width = 8
-large_height = 5.25
+if (requireNamespace("pkgdown", quietly = TRUE) && pkgdown::in_pkgdown()) {
+  tiny_width = 5.5
+  tiny_height = 3 + 2/3
+  small_width = med_width = 6.75
+  small_height = med_height = 4.5
+  large_width = 8
+  large_height = 5.25
+} else {
+  tiny_width = 5
+  tiny_height = 3 + 1/3
+  small_width = 5
+  small_height = 3 + 1/3
+  med_width = 5
+  med_height = 3 + 1/3
+  large_width = 5.5
+  large_height = 2/3
+}
 
 knitr::opts_chunk$set(
   fig.width = small_width,
@@ -116,7 +127,7 @@ dists_plot = dists_df %>%
   stat_gradientinterval(data = dists_df_("gradientinterval"), scale = .5, fill_type = "gradient") +
   stat_ccdfinterval(data = dists_df_("ccdfinterval"), scale = .5) +
   stat_cdfinterval(data = dists_df_("cdfinterval"), scale = .5) +
-  stat_interval(data = dists_df_("interval"), color = "gray65", alpha = 1/3, size = 10,
+  stat_interval(data = dists_df_("interval"), color = "gray65", alpha = 1/3, linewidth = 10,
     position = position_nudge(y = -.1)) +
   stat_pointinterval(data = dists_df_("pointinterval")) +
   stat_slab(data = dists_df_("slab"), position = position_nudge(y = - 0.2)) +
@@ -168,7 +179,7 @@ blue_ = "#7570b3"
 bracket_ = function(..., x, xend = x, y, yend = y, color = red_) {
   annotate("segment",
     arrow = arrow(angle = 90, ends = "both", length = unit(3, "points")),
-    color = color, size = 0.75,
+    color = color, linewidth = 0.75,
     x = x, xend = xend, y = y, yend = yend,
     ...
   )
@@ -177,7 +188,7 @@ thickness_ = function(x) dnorm(x,4,1) * 0.9 / dnorm(4,4,1)
 thickness_bracket_ = function(x) bracket_(x = x, y = 0, yend = thickness_(x))
 refline_ = function(..., x, xend = x, y, yend = y, color = red_, linetype = "solid", alpha = 0.5) {
   annotate("segment",
-    color = color, linetype = linetype, alpha = alpha, size = 0.75,
+    color = color, linetype = linetype, alpha = alpha, linewidth = 0.75,
     x = x, xend = xend, y = y, yend = yend,
     ...
   )
@@ -201,7 +212,7 @@ arrow_ = function(..., curvature = 0, x, xend = x, y, yend = y) {
 dists_df_("halfeye") %>%
   ggplot(aes(y = 0, xdist = dist)) +
   stat_slabinterval(
-    aes(interval_size = NULL),
+    aes(linewidth = NULL),
     slab_color = "black", 
     expand = FALSE, 
     limits = c(0, 8), 
@@ -210,7 +221,7 @@ dists_df_("halfeye") %>%
     point_size = 3,
     shape = 21,
     stroke = 1.5,
-    interval_size = 3,
+    linewidth = 3,
   ) +
   
   # height
@@ -234,7 +245,7 @@ dists_df_("halfeye") %>%
   
   # slab line properties
   label_(x = 2.5, y = 0.7, 
-    label = 'slab_color = "black"\nslab_size = 1\nslab_linetype = linetype = "solid"',
+    label = 'slab_color = "black"\nslab_linewidth = 1\nslab_linetype = linetype = "solid"',
     vjust = 1, hjust = 1
   ) +
   arrow_(x = 2.52, xend = 3.08, y = 0.67, yend = thickness_(3.08) + 0.03, curvature = -0.2) +
@@ -256,7 +267,7 @@ dists_df_("halfeye") %>%
   
   # interval properties
   label_(x = 3.5, y = -0.2,
-    label = 'interval_color = color = "black"\ninterval_alpha = alpha = 1\ninterval_linetype = linetype = "solid"\ninterval_size = size = 3',
+    label = 'interval_color = color = "black"\ninterval_alpha = alpha = 1\ninterval_linetype = linetype = "solid"\nlinewidth = size = 3',
     vjust = 1, hjust = 1
   ) +
   arrow_(x = 3.3, xend = 3.4, y = -0.18, yend = -0.01, curvature = -0.1) +
@@ -283,17 +294,11 @@ df = tribble(
   ) %>%
   unnest(value)
 
-## ----group_eye, fig.width = small_height, fig.height = small_height---------------------------------------------------
-df %>%
-  ggplot(aes(y = group, x = value)) +
-  stat_eye() +
-  ggtitle("stat_eye()")
-
-## ----group_halfeye, fig.width = small_height, fig.height = small_height-----------------------------------------------
+## ----group_halfeye, fig.width = tiny_height, fig.height = tiny_height-------------------------------------------------
 df %>%
   ggplot(aes(y = group, x = value)) +
   stat_halfeye() +
-  ggtitle("stat_halfeye()")
+  ggtitle("stat_halfeye() (or stat_slabinterval())")
 
 ## ----eye_side, fig.width = med_width, fig.height = small_height-------------------------------------------------------
 p = df %>%
@@ -301,17 +306,11 @@ p = df %>%
   panel_border()
 
 plot_grid(ncol = 3, align = "hv",
-  p + stat_eye(side = "left") + labs(title = "stat_eye()", subtitle = "side = 'left'"),
-  p + stat_eye(side = "both") + labs(subtitle = "side = 'both'"),
-  p + stat_eye(side = "right")  + labs(subtitle = "side = 'right'")
+  p + stat_slabinterval(side = "left") + labs(title = "stat_slabinterval()", subtitle = "side = 'left'"),
+  p + stat_slabinterval(side = "both") + labs(subtitle = "side = 'both'"),
+  p + stat_slabinterval(side = "right")  + labs(subtitle = "side = 'right'")
 )
 
-## ----halfeyeh, fig.width = small_height, fig.height = small_height----------------------------------------------------
-df %>%
-  ggplot(aes(x = group, y = value)) +
-  stat_halfeye() +
-  ggtitle("stat_halfeye()")
-
 ## ----eyeh_side, fig.width = med_width, fig.height = small_height------------------------------------------------------
 p = df %>%
   ggplot(aes(x = value, y = group)) +
@@ -319,10 +318,10 @@ p = df %>%
 
 plot_grid(ncol = 3, align = "hv", 
   # side = "left" would give the same result
-  p + stat_eye(side = "left") + ggtitle("stat_eye()") + labs(subtitle = "side = 'bottom'"),
-  p + stat_eye(side = "both") + labs(subtitle = "side = 'both'"),
+  p + stat_slabinterval(side = "left") + ggtitle("stat_slabinterval()") + labs(subtitle = "side = 'bottom'"),
+  p + stat_slabinterval(side = "both") + labs(subtitle = "side = 'both'"),
   # side = "right" would give the same result
-  p + stat_eye(side = "right") + labs(subtitle = "side = 'top'")
+  p + stat_slabinterval(side = "right") + labs(subtitle = "side = 'top'")
 )
 
 ## ----eye_dodge--------------------------------------------------------------------------------------------------------
@@ -341,12 +340,6 @@ dist_df = tribble(
     "c",          "j",     7,   1
 )
 
-## ----dist_eye_dodge---------------------------------------------------------------------------------------------------
-dist_df %>%
-  ggplot(aes(x = group, ydist = "norm", arg1 = mean, arg2 = sd, fill = subgroup)) +
-  stat_eye(position = "dodge") +
-  ggtitle("stat_eye(position = 'dodge')", 'aes(ydist = "norm", arg1 = mean, arg2 = sd)')
-
 ## ----dist_eye_dodge_distributional------------------------------------------------------------------------------------
 dist_df %>%
   ggplot(aes(x = group, ydist = dist_normal(mean, sd), fill = subgroup)) +
@@ -376,21 +369,13 @@ data.frame(alpha = seq(5, 100, length.out = 10)) %>%
     y = NULL
   )
 
-## ----norm_vs_t, fig.width = small_height, fig.height = small_height---------------------------------------------------
-tribble(
-  ~ dist,      ~ args,
-  "norm",      list(0, 1),
-  "student_t", list(3, 0, 1)
-) %>%
-  ggplot(aes(y = dist, xdist = dist, args = args)) +
-  stat_halfeye() +
-  ggtitle("stat_halfeye()", "aes(xdist = dist, args = args)")
-
 ## ----priors_fake, eval=FALSE------------------------------------------------------------------------------------------
 #  # NB these priors are made up!
 #  priors = c(
-#    prior(normal(0,1), class = b),
-#    prior(lognormal(0,1), class = sigma)
+#    prior(normal(1, 0.5), class = b),
+#    prior(gamma(2, 2), class = phi),
+#    # lb = 0 sets a lower bound of 0, i.e. a half-Normal distribution
+#    prior(normal(0, 1), class = sigma, lb = 0)
 #  )
 #  priors
 
@@ -398,13 +383,14 @@ tribble(
 # we want to avoid a brms dependency, so we fake it above and
 # just show the output of brms::prior() here
 priors = data.frame(
-  prior = c("normal(0, 1)", "lognormal(0, 1)"),
-  class = c("b", "sigma"), coef = c("", ""),
-  group = c("", ""),
-  resp = c("", ""),
-  dpar = c("", ""),
-  nlpar = c("", ""),
-  bound = c("", "")
+  prior = c("normal(1, 0.5)", "gamma(2, 2)", "normal(0, 1)"),
+  class = c("b", "phi", "sigma"), coef = c("", "", ""),
+  group = c("", "", ""),
+  resp = c("", "", ""),
+  dpar = c("", "", ""),
+  nlpar = c("", "", ""),
+  lb = c(NA, NA, "0"),
+  ub = c(NA, NA, NA)
 )
 priors
 
@@ -415,17 +401,41 @@ priors %>%
 ## ----prior_dist_halfeyeh----------------------------------------------------------------------------------------------
 priors %>%
   parse_dist(prior) %>%
-  ggplot(aes(y = class, xdist = .dist, args = .args)) +
+  ggplot(aes(y = paste(class, "~", format(.dist_obj)), xdist = .dist_obj)) +
   stat_halfeye() +
   labs(
     title = "stat_halfeye()",
     subtitle = "with brms::prior() and ggdist::parse_dist() to visualize priors",
-    x = NULL
+    x = NULL,
+    y = NULL
   )
 
-## ----dist_halfeyeh_log_scale, fig.width = small_height, fig.height = small_height/1.5---------------------------------
-data.frame(dist = "lnorm", logmean = log(10), logsd = 2*log(10)) %>%
-  ggplot(aes(xdist = dist, arg1 = logmean, arg2 = logsd)) +
+## ----prior_post, fig.width = med_width, fig.height = small_height * 2/3-----------------------------------------------
+prior_post = data.frame(
+ prior = dist_normal(0, 1),
+ posterior = dist_normal(0.1, 0.5)
+)
+
+separate_scale_plot = prior_post %>%
+  ggplot() +
+  stat_halfeye(aes(xdist = posterior)) +
+  stat_slab(aes(xdist = prior), fill = NA, color = "red") +
+  labs(
+    subtitle = "default: no shared thickness scale"
+  )
+
+shared_scale_plot = prior_post %>%
+  ggplot() +
+  stat_halfeye(aes(xdist = posterior)) +
+  stat_slab(aes(xdist = prior), fill = NA, color = "#e41a1c") +
+  scale_thickness_shared() +
+  labs(subtitle = "with scale_thickness_shared()")
+
+separate_scale_plot + shared_scale_plot + plot_annotation(title = "prior (slab) + posterior (halfeye)")
+
+## ----dist_halfeyeh_log_scale, fig.width = small_height, fig.height = small_height/1.75--------------------------------
+data.frame(dist = dist_lognormal(log(10), 2*log(10))) %>%
+  ggplot(aes(xdist = dist)) +
   stat_halfeye() +
   scale_x_log10(breaks = 10^seq(-5,7, by = 2))
 
@@ -457,27 +467,11 @@ tibble(
   lambda = c(13,7,4,3,2)
 ) %>%
   ggplot(aes(x = group)) +
-  stat_slab(aes(ydist = dist_poisson(lambda), fill = stat(pdf))) +
-  geom_line(aes(y = lambda, group = NA), size = 1) +
+  stat_slab(aes(ydist = dist_poisson(lambda), fill = after_stat(pdf))) +
+  geom_line(aes(y = lambda, group = NA), linewidth = 1) +
   geom_point(aes(y = lambda), size = 2.5) +
   labs(fill = "Pr(y)") +
-  ggtitle("stat_slab()", "aes(ydist = dist_poisson(lambda), fill = stat(pdf))")
-
-## ----cdfinterval_family, fig.width = med_width, fig.height = med_width------------------------------------------------
-p = df %>%
-  ggplot(aes(x = group, y = value)) +
-  panel_border()
-
-ph = df %>%
-  ggplot(aes(y = group, x = value)) +
-  panel_border()
-
-plot_grid(ncol = 2, align = "hv",
-  p + stat_ccdfinterval() + labs(title = "stat_ccdfinterval()", subtitle = "vertical"),
-  ph + stat_ccdfinterval() + labs(subtitle = "horizontal"),
-  p + stat_cdfinterval() + labs(title = "stat_cdfinterval()", subtitle = "vertical"),
-  ph + stat_cdfinterval()  + labs(subtitle = "horizontal")
-)
+  ggtitle("stat_slab()", "aes(ydist = dist_poisson(lambda), fill = after_stat(pdf))")
 
 ## ----ccdf_barplot-----------------------------------------------------------------------------------------------------
 df %>%
@@ -485,15 +479,6 @@ df %>%
   stat_ccdfinterval(position = "dodge") +
   ggtitle("stat_ccdfinterval(position = 'dodge')") 
 
-## ----ccdf_dodge-------------------------------------------------------------------------------------------------------
-df %>%
-  ggplot(aes(x = group, y = value, fill = subgroup)) +
-  stat_ccdfinterval(position = "dodge") +
-  expand_limits(y = 0) +
-  # plus coord_cartesian so there is no space between bars and axis
-  coord_cartesian(expand = FALSE) +
-  ggtitle("stat_ccdfinterval(position = 'dodge')")
-
 ## ----ccdf_justification-----------------------------------------------------------------------------------------------
 df %>%
   ggplot(aes(x = group, y = value, fill = subgroup)) +
@@ -502,31 +487,6 @@ df %>%
   coord_cartesian(expand = FALSE) +
   ggtitle("stat_ccdfinterval(position = 'dodge', justification = 1)")
 
-## ----ccdf_side, fig.width = med_width, fig.height = med_height--------------------------------------------------------
-p = df %>%
-  ggplot(aes(x = value, y = group)) +
-  expand_limits(x = 0) +
-  panel_border()
-
-plot_grid(ncol = 3, align = "hv", 
-  # side = "left" would give the same result
-  p + stat_ccdfinterval(side = "bottom") + ggtitle("stat_ccdfinterval()") + labs(subtitle = "side = 'bottom'"),
-  p + stat_ccdfinterval(side = "both") + labs(subtitle = "side = 'both'"),
-  # side = "right" would give the same result
-  p + stat_ccdfinterval(side = "top") + labs(subtitle = "side = 'top'")
-)
-
-## ----dist_ccdf_dodge--------------------------------------------------------------------------------------------------
-dist_df %>%
-  ggplot(aes(x = group, ydist = dist_normal(mean, sd), fill = subgroup)) +
-  stat_ccdfinterval(position = "dodge") +
-  expand_limits(y = 0) +
-  ggtitle(
-    "stat_ccdfinterval(position = 'dodge')",
-    "aes(x = dist_normal(mean, sd)) + expand_limits(y = 0)"
-  ) +
-  coord_cartesian(expand = FALSE)
-
 ## ----gradient_dodge---------------------------------------------------------------------------------------------------
 df %>%
   ggplot(aes(x = group, y = value, fill = subgroup)) +
@@ -539,15 +499,6 @@ df %>%
   stat_gradientinterval(position = "dodge", fill_type = "gradient") +
   labs(title = "stat_gradientinterval(position = 'dodge', fill_type = 'gradient')")
 
-## ----dist_gradient_dodge----------------------------------------------------------------------------------------------
-dist_df %>%
-  ggplot(aes(x = group, ydist = dist_normal(mean, sd), fill = subgroup)) +
-  stat_gradientinterval(position = "dodge", fill_type = "gradient") +
-  labs(
-    title = "stat_gradientinterval(position = 'dodge')",
-    subtitle = "aes(ydist = dist_normal(mean, sd), fill = subgroup)"
-  )
-
 ## ----dots_dodge_nocolor, fig.width = med_width, fig.height = small_height---------------------------------------------
 df %>%
   ggplot(aes(x = group, y = value, fill = subgroup, color = subgroup)) +
@@ -566,68 +517,66 @@ df %>%
 ## ----ccdf_gradient, fig.width = med_width, fig.height = small_height--------------------------------------------------
 df %>%
   ggplot(aes(x = group, y = value, fill = subgroup)) +
-  stat_ccdfinterval(aes(slab_alpha = stat(f)), 
+  stat_ccdfinterval(aes(slab_alpha = after_stat(f)), 
     thickness = 1, position = "dodge", fill_type = "gradient"
   ) +
   expand_limits(y = 0) +
   # plus coord_cartesian so there is no space between bars and axis
   coord_cartesian(expand = FALSE) +
-  ggtitle("stat_ccdfinterval(thickness = 1)", "aes(slab_alpha = stat(f))")
+  ggtitle("stat_ccdfinterval(thickness = 1)", "aes(slab_alpha = after_stat(f))")
 
-## ----norm_vs_t_highlight, fig.width = med_width, fig.height = small_height--------------------------------------------
-priors = tribble(
-  ~ dist,      ~ args,
-  "norm",      list(0, 1),
-  "student_t", list(3, 0, 1)
+## ----norm_vs_t_highlight, fig.width = small_width, fig.height = small_height------------------------------------------
+priors = tibble(
+  dist = c(dist_normal(0, 1), dist_student_t(3, 0, 1))
 ) 
 
 priors %>%
-  ggplot(aes(y = dist, xdist = dist, args = args)) +
-  stat_halfeye(aes(fill = stat(abs(x) < 1.5))) +
-  ggtitle("stat_halfeye()", "aes(fill = stat(abs(x) < 1.5)))") +
+  ggplot(aes(y = format(dist), xdist = dist)) +
+  stat_halfeye(aes(fill = after_stat(abs(x) < 1.5))) +
+  ggtitle("stat_halfeye()", "aes(fill = after_stat(abs(x) < 1.5)))") +
   # we'll use a nicer palette than the default for highlighting:
   scale_fill_manual(values = c("gray85", "skyblue"))
 
-## ----norm_vs_t_gradient_eye, fig.width = med_width, fig.height = small_height-----------------------------------------
+## ----norm_vs_t_gradient_eye, fig.width = small_width, fig.height = small_height---------------------------------------
 priors %>%
-  ggplot(aes(y = dist, xdist = dist, args = args)) +
-  stat_eye(aes(slab_alpha = stat(f), fill = stat(x > 1)), fill_type = "gradient") +
+  ggplot(aes(y = format(dist), xdist = dist)) +
+  stat_eye(aes(slab_alpha = after_stat(f), fill = after_stat(x > 1)), fill_type = "gradient") +
   ggtitle(
     "stat_eye(fill_type = 'gradient')", 
-    "aes(slab_alpha = stat(f), fill = stat(x > 1)))"
+    "aes(slab_alpha = after_stat(f), fill = after_stat(x > 1)))"
   ) +
   # we'll use a nicer palette than the default for highlighting:
   scale_fill_manual(values = c("gray75", "skyblue"))
 
-## ----correll_gradient, fig.width = small_width, fig.height = small_height/2-------------------------------------------
+## ----correll_gradient, fig.width = small_width, fig.height = small_height/1.75----------------------------------------
 priors %>%
-  ggplot(aes(y = dist, xdist = dist, args = args)) +
-  stat_gradientinterval(aes(slab_alpha = stat(-pmax(abs(1 - 2*cdf), .95))),
+  ggplot(aes(y = format(dist), xdist = dist)) +
+  stat_gradientinterval(aes(slab_alpha = after_stat(-pmax(abs(1 - 2*cdf), .95))),
     fill_type = "gradient"
   ) +
   scale_slab_alpha_continuous(guide = "none") +
   ggtitle(
     "stat_gradientinterval(fill_type = 'gradient')",
-    "aes(slab_alpha = stat(-pmax(abs(1 - 2*cdf), .95)))"
+    "aes(slab_alpha = after_stat(-pmax(abs(1 - 2*cdf), .95)))"
   )
 
-## ----helske_gradient_eye, fig.width = med_width, fig.height = small_height--------------------------------------------
+## ----helske_gradient_eye, fig.width = small_width, fig.height = small_height------------------------------------------
 priors %>%
-  ggplot(aes(y = dist, xdist = dist, args = args)) +
-  stat_eye(aes(slab_alpha = stat(-pmax(abs(1 - 2*cdf), .95))), fill_type = "gradient") +
+  ggplot(aes(y = format(dist), xdist = dist)) +
+  stat_eye(aes(slab_alpha = after_stat(-pmax(abs(1 - 2*cdf), .95))), fill_type = "gradient") +
   scale_slab_alpha_continuous(guide = "none") +
   ggtitle(
     "stat_eye(fill_type = 'gradient')",
-    "aes(slab_alpha = stat(-pmax(abs(1 - 2*cdf), .95)))"
+    "aes(slab_alpha = after_stat(-pmax(abs(1 - 2*cdf), .95)))"
   )
 
-## ----tukey_pencils, fig.width = small_height * 1.25, fig.height = small_height----------------------------------------
+## ----tukey_pencils, fig.width = small_width, fig.height = small_height------------------------------------------------
 dist_df %>%
   ggplot(aes(x = group, ydist = dist_normal(mean, sd), fill = subgroup)) +
   stat_slab(
     aes(
-      thickness = stat(pmax(0, abs(1 - 2*cdf) - .95)), 
-      fill_ramp = stat(pmax(0, abs(1 - 2*cdf) - .95))
+      thickness = after_stat(pmax(0, abs(1 - 2*cdf) - .95)), 
+      fill_ramp = after_stat(pmax(0, abs(1 - 2*cdf) - .95))
     ),
     side = "both", position = "dodge", fill_type = "gradient"
   ) +
@@ -635,50 +584,80 @@ dist_df %>%
     title = 'stat_slab(side = "both")', 
     subtitle = paste0(
       "aes(fill = subgroup,\n       ",
-      "fill_ramp and thickness = stat(pmax(0, abs(1 - 2*cdf) - .95)))"
+      "fill_ramp and thickness = after_stat(pmax(0, abs(1 - 2*cdf) - .95)))"
     )
   ) +
   guides(fill_ramp = "none") +
   coord_cartesian(expand = FALSE)
 
-## ----halfeye_filled_intervals, fig.width = med_width, fig.height = small_height---------------------------------------
+## ----halfeye_filled_intervals, fig.width = small_width, fig.height = small_height-------------------------------------
 df %>%
   ggplot(aes(y = group, x = value)) +
-  stat_halfeye(aes(fill = stat(cut_cdf_qi(cdf)))) +
-  scale_fill_brewer(direction = -1) +
+  stat_halfeye(aes(fill = after_stat(level))) +
+  # na.translate = FALSE drops the unnecessary NA from the legend, which covers
+  # slab values outside the intervals. An alternative would be to use 
+  # na.value = ... to set the color for values outside the intervals.
+  scale_fill_brewer(na.translate = FALSE) +
   labs(
     title = "stat_halfeye()", 
-    subtitle = "aes(fill = stat(cut_cdf_qi(cdf)))",
-    fill = "Interval"
+    subtitle = "aes(fill = after_stat(level))",
+    fill = "interval"
   )
 
-## ----halfeye_filled_intervals_2, fig.width = med_width, fig.height = small_height-------------------------------------
+## ----halfeye_filled_intervals_2, fig.width = small_width, fig.height = small_height-----------------------------------
 df %>%
   ggplot(aes(y = group, x = value)) +
-  stat_halfeye(aes(fill = stat(cut_cdf_qi(
-    cdf, 
-    .width = c(.5, .8, .95),
-    labels = scales::percent_format()
-  )))) +
-  scale_fill_brewer(direction = -1, na.translate = FALSE) +
+  stat_slab(aes(fill = after_stat(level)), .width = c(.66, .95, 1)) +
+  stat_pointinterval() +
+  scale_fill_brewer() +
   labs(
-    title = "stat_halfeye()", 
-    subtitle = "aes(fill = stat(cut_cdf_qi(cdf, .width = c(.5, .8, .95))))",
-    fill = "Interval"
+    title = "stat_slab()", 
+    subtitle = "aes(fill = after_stat(level), .width = c(.66, .95, 1))",
+    fill = "interval"
   )
 
-## ----halfeye_filled_intervals_subgroup, fig.width = med_width, fig.height = small_height------------------------------
+## ----halfeye_qi_vs_hdi, fig.width = small_width, fig.height = small_height--------------------------------------------
+qi_plot = data.frame(dist = dist_beta(10, 2)) %>%
+  ggplot(aes(xdist = dist)) + 
+  stat_halfeye(aes(fill = after_stat(level)), point_interval = median_qi, .width = c(.5, .8, .95)) + 
+  scale_fill_brewer(na.value = "gray95") +
+  labs(subtitle = "stat_halfeye(aes(fill = after_stat(level)), point_interval = median_qi)")
+
+hdi_plot = data.frame(dist = dist_beta(10, 2)) %>%
+  ggplot(aes(xdist = dist)) + 
+  stat_halfeye(aes(fill = after_stat(level)), point_interval = mode_hdci, .width = c(.5, .8, .95)) + 
+  scale_fill_brewer(na.value = "gray95") +
+  labs(subtitle = "stat_halfeye(aes(fill = after_stat(level)), point_interval = mode_hdci)")
+
+qi_plot /
+  hdi_plot
+
+## ----halfeye_qi_vs_hdi_spikes, fig.width = small_width, fig.height = small_height-------------------------------------
+qi_plot_spikes = data.frame(dist = dist_beta(10, 2)) %>%
+  ggplot(aes(xdist = dist)) + 
+  stat_slab(aes(fill = after_stat(level)), point_interval = median_qi, .width = c(.5, .95)) + 
+  stat_spike(at = c(median, qi)) + 
+  scale_fill_brewer(na.value = "gray95") +
+  scale_thickness_shared() +
+  labs(subtitle = "stat_slab() + stat_spike(at = c(median, qi))")
+
+hdi_plot_spikes = data.frame(dist = dist_beta(10, 2)) %>%
+  ggplot(aes(xdist = dist)) + 
+  stat_slab(aes(fill = after_stat(level)), point_interval = mode_hdci, .width = c(.5, .95)) + 
+  stat_spike(at = c(Mode, hdci)) +
+  scale_fill_brewer(na.value = "gray95") +
+  scale_thickness_shared() +
+  labs(subtitle = "stat_slab() + stat_spike(at = c(Mode, hdci))")
+
+qi_plot_spikes /
+  hdi_plot_spikes
+
+## ----halfeye_filled_intervals_subgroup, fig.width = small_width, fig.height = small_height----------------------------
 df %>%
   ggplot(aes(y = group, x = value)) +
   stat_halfeye(
-    aes(
-      fill = subgroup,
-      fill_ramp = stat(cut_cdf_qi(
-        cdf, 
-        .width = c(.5, .8, .95),
-        labels = scales::percent_format()
-      ))
-    ),
+    aes(fill = subgroup, fill_ramp = after_stat(level)),
+    .width = c(.50, .80, .95),
     # NOTE: we use position = "dodgejust" (a dodge that respects the 
     # justification of intervals relative to slabs) instead of 
     # position = "dodge" here because it ensures the topmost slab does
@@ -687,23 +666,40 @@ df %>%
   ) +
   # a range from 1 down to 0.2 ensures the fill goes dark to light inside-out
   # and doesn't get all the way down to white (0) on the lightest color
-  scale_fill_ramp_discrete(range = c(1, 0.2), na.translate = FALSE) +
+  scale_fill_ramp_discrete(na.translate = FALSE) +
   labs(
     title = "stat_halfeye(position = 'dodgejust')", 
-    subtitle = "aes(fill = subgroup, fill_ramp = stat(cut_cdf_qi(cdf)))",
-    fill_ramp = "Interval"
+    subtitle = "aes(fill = subgroup, fill_ramp = after_stat(level))",
+    fill_ramp = "interval"
   )
 
-## ----dist_interval_color_ramp, fig.width = med_width, fig.height = small_height---------------------------------------
+## ----dist_interval_color_ramp, fig.width = small_width, fig.height = small_height-------------------------------------
 dist_df %>%
   ggplot(aes(x = group, ydist = dist_normal(mean, sd), color = subgroup)) +
-  stat_interval(aes(color_ramp = stat(level)), position = "dodge") +
+  stat_interval(aes(color_ramp = after_stat(level)), position = "dodge") +
   labs(
     title = "stat_interval()", 
-    subtitle = "aes(color = subgroup, color_ramp = stat(level))"
+    subtitle = "aes(color = subgroup, color_ramp = after_stat(level))"
   )
 
-## ----slab_ridge, fig.width = med_width, fig.height = small_height-----------------------------------------------------
+## ----raindrop, fig.width = small_width, fig.height = small_height/1.5-------------------------------------------------
+priors %>%
+  ggplot(aes(y = format(dist), xdist = dist)) +
+  # must also use normalize = "groups" because min(log(pdf)) will be different for each dist
+  stat_slab(
+    aes(thickness = after_stat(ifelse(.width <= 0.99, log(pdf), NA))), 
+    normalize = "groups", fill = "gray85", .width = .99, side = "both"
+  ) +
+  stat_eye(
+    aes(thickness = after_stat(ifelse(.width <= 0.95, log(pdf), NA))), 
+    normalize = "groups"
+  ) +
+  ggtitle(
+    'stat_eye(normalize = "groups")',
+    "with aes(thickness = after_stat(ifelse(.width <= 0.95, log(pdf), NA)))\nand aes(thickness = after_stat(ifelse(.width <= 0.99, log(pdf), NA)))"
+  )
+
+## ----slab_ridge, fig.width = small_width, fig.height = small_height---------------------------------------------------
 set.seed(1234)
 
 ridges_df = data.frame(
@@ -716,27 +712,27 @@ ridges_df %>%
   stat_slab(height = 2, color = "black") +
   ggtitle("stat_slab(height = 2, color = 'black')")
 
-## ----slab_ridge_ramp, fig.width = med_width, fig.height = small_height------------------------------------------------
+## ----slab_ridge_ramp, fig.width = small_width, fig.height = small_height----------------------------------------------
 ridges_df %>%
   ggplot(aes(
     y = group, x = x, 
-    fill = group, fill_ramp = stat(abs(x)), 
-    color_ramp = stat(-dnorm(x, 0, 2))
+    fill = group, fill_ramp = after_stat(abs(x)), 
+    color_ramp = after_stat(-dnorm(x, 0, 2))
   )) +
   stat_slab(
     height = 2, color = "gray15", 
-    expand = TRUE, trim = FALSE, 
+    expand = TRUE, trim = FALSE, density = "unbounded",
     fill_type = "gradient", 
     show.legend = FALSE
   ) +
   geom_vline(xintercept = 0, color = "gray85", linetype = "dashed") +
   ggtitle(
     'stat_slab(height = 2, color = "black", expand = TRUE, trim = FALSE)',
-    'aes(fill = group, fill_ramp = stat(abs(x)), color_ramp = stat(-dnorm(x, 0, 2)))'
+    'aes(fill = group, fill_ramp = after_stat(abs(x)), color_ramp = after_stat(-dnorm(x, 0, 2)))'
   ) +
   scale_fill_viridis_d()
 
-## ----varying_side_dotplot, fig.width = med_width, fig.height = small_height-------------------------------------------
+## ----varying_side_dotplot, fig.width = small_width, fig.height = small_height-----------------------------------------
 dist_df %>%
   filter(subgroup == "h") %>%
   mutate(side = c("top", "both", "bottom")) %>%
@@ -748,7 +744,7 @@ dist_df %>%
   ) +
   coord_cartesian()
 
-## ----halfeye_quantile_dotplot, fig.width = med_width, fig.height = small_height---------------------------------------
+## ----halfeye_quantile_dotplot, fig.width = small_width, fig.height = small_height-------------------------------------
 df %>%
   ggplot(aes(x = group, y = value, fill = subgroup)) +
   stat_slab(side = "left", scale = 0.5, position = "dodge") +
@@ -766,7 +762,7 @@ df %>%
     'stat_pointinterval(geom = "label")'
   ))
 
-## ----slab_and_pointinterval, fig.width = med_width, fig.height = small_height-----------------------------------------
+## ----slab_and_pointinterval, fig.width = small_width, fig.height = small_height/1.25----------------------------------
 df %>%
   ggplot(aes(fill = group, color = group, x = value)) +
   stat_slab(alpha = .3) +
